@@ -3,7 +3,7 @@ knitr::opts_chunk$set(warning = FALSE,
                       message = FALSE,
                       collapse = TRUE,
                       comment = "#>",
-                      out.width = "\\textwidth", 
+                      out.width = "100%", 
                       fig.height = 5, 
                       fig.width = 7, 
                       fig.align = "center")
@@ -12,28 +12,36 @@ knitr::opts_chunk$set(eval = nzchar(Sys.getenv("BUILD_VIGNETTES")))
 
 ## ----load_pipd----------------------------------------------------------------
 #  library(ebirdst)
-#  
-#  # DOWNLOAD DATA
-#  # Currently, example data is available on a public s3 bucket. The following
-#  # ebirdst_download() function copies the species results to a selected path and
-#  # returns the full path of the results.
+#  library(dplyr)
 #  
 #  # Because the non-raster data is large, there is a parameter on the
 #  # ebirdst_download function that defaults to downloading only the raster data.
 #  # To access the non-raster data, set tifs_only = FALSE.
 #  sp_path <- ebirdst_download(species = "example_data", tifs_only = FALSE)
-#  print(sp_path)
 #  
+#  # predictor importance
 #  pis <- load_pis(sp_path)
+#  glimpse(pis)
+#  
+#  # partial dependence
+#  pds <- load_pds(sp_path)
+#  glimpse(pds)
 
-## ----map_centroids------------------------------------------------------------
+## ----extent-------------------------------------------------------------------
+#  # define a spatiotemporal extent
 #  lp_extent <- ebirdst_extent(c(xmin = -86, xmax = -83, ymin = 42, ymax = 45),
 #                              t = c(0.425, 0.475))
-#  map_centroids(sp_path, ext = lp_extent)
+#  print(lp_extent)
+#  
+#  # subset to this extent
+#  pis_ss <- ebirdst_subset(pis, ext = lp_extent)
+#  nrow(pis)
+#  nrow(pis_ss)
 
 ## ----plot_extents-------------------------------------------------------------
 #  par(mfrow = c(1, 1), mar = c(0, 0, 0, 6))
-#  calc_effective_extent(sp_path, ext = lp_extent)
+#  footprint <- stixel_footprint(sp_path, ext = lp_extent)
+#  plot(footprint)
 
 ## ----plot_pis-----------------------------------------------------------------
 #  # with all classes
@@ -42,9 +50,23 @@ knitr::opts_chunk$set(eval = nzchar(Sys.getenv("BUILD_VIGNETTES")))
 #  # aggregating fragstats for cover classes
 #  plot_pis(pis, ext = lp_extent, by_cover_class = TRUE, n_top_pred = 15)
 
+## ----plot_pds-----------------------------------------------------------------
+#  # in the interest of speed, run with 5 bootstrap iterations
+#  # in practice, best to run with the default number of iterations (100)
+#  pd_smooth <- plot_pds(pds, "solar_noon_diff", ext = lp_extent, n_bs = 5)
+#  dplyr::glimpse(pd_smooth)
+#  
+#  # deciduous broadleaf forest
+#  plot_pds(pds, "mcd12q1_lccs1_fs_c14_1500_pland", ext = lp_extent, n_bs = 5)
+
+## ----ppms---------------------------------------------------------------------
+#  ppms <- ebirdst_ppms(sp_path, ext = lp_extent)
+#  plot(ppms)
+
 ## ----binary_by_time-----------------------------------------------------------
-#  plot_binary_by_time(path = sp_path, metric = "kappa", n_time_periods = 12)
-
-## ----all_ppms-----------------------------------------------------------------
-#  plot_all_ppms(sp_path, lp_extent)
+#  ppms_monthly <- ebirdst_ppms_ts(sp_path, ext = lp_extent, summarize_by = "months")
+#  # plot binary kappa
+#  plot(ppms_monthly, type = "binary", metric = "kappa")
+#  # plot occurrence probability auc
+#  plot(ppms_monthly, type = "occurrence", metric = "auc")
 
